require 'touggsl'
require 'json'
require 'touggsl/request_helpers'

class Touggsl::Auth
  
  class << self
    
    include Touggsl::RequestHelper

    attr_accessor :session
    attr_accessor :status
    
    ##
    # Autentica o usuário na Superlogica
    #
    # === Params
    #
    # * <tt>username</tt> - O e-mail que voce utiliza para logar no sistema da Suerlogica
    # * <tt>passoword</tt> - sua senha
    #
    # === Exceptions
    # Uma excesao eh lancada caso o username ou a senha estejam incorretos
    #
    def login(username, password)
      response = do_request(username,password)
      json = JSON.parse(response)
      @status = json["status"]  
      if @status == "401"
        @session = nil
        raise "Invalid username or password!"
      end
      @session = json["session"]
      @cookie = response.request.options[:headers]['Cookie']
      json
    end
    
    ##
    # Retorna a sessao da autenticacao
    #
    def get_session
     @session 
    end
  
    ##
    # Retorna o status da autenticacao.
    #
    # Os status seguem o padrao HTTP
    #
    def get_status
      @status
    end

    ##
    # Retorna um cookie da autenticacao. Esse cookie eh usado
    # em todas as futuras autenticacoes, assim voce nao precisa logar
    # novamente
    #
    def get_cookie
     @cookie 
    end
  end

end
